==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1RunAsUserStrategyOptionsFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ExtensionsV1beta1RunAsUserStrategyOptionsFluent<A extends ExtensionsV1beta1RunAsUserStrategyOptionsFluent<A>> extends Fluent<A>{


    public A addToRanges(int index,ExtensionsV1beta1IDRange item);
    public A setToRanges(int index,ExtensionsV1beta1IDRange item);
    public A addToRanges(ExtensionsV1beta1IDRange... items);
    public A addAllToRanges(Collection<ExtensionsV1beta1IDRange> items);
    public A removeFromRanges(ExtensionsV1beta1IDRange... items);
    public A removeAllFromRanges(Collection<ExtensionsV1beta1IDRange> items);
    
/**
 * This method has been deprecated, please use method buildRanges instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1IDRange> getRanges();
    public List<ExtensionsV1beta1IDRange> buildRanges();
    public ExtensionsV1beta1IDRange buildRange(int index);
    public ExtensionsV1beta1IDRange buildFirstRange();
    public ExtensionsV1beta1IDRange buildLastRange();
    public ExtensionsV1beta1IDRange buildMatchingRange(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IDRangeBuilder> predicate);
    public A withRanges(List<ExtensionsV1beta1IDRange> ranges);
    public A withRanges(ExtensionsV1beta1IDRange... ranges);
    public Boolean hasRanges();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> addNewRange();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> addNewRangeLike(ExtensionsV1beta1IDRange item);
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> setNewRangeLike(int index,ExtensionsV1beta1IDRange item);
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editRange(int index);
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editFirstRange();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editLastRange();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editMatchingRange(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IDRangeBuilder> predicate);
    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();

    public interface RangesNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IDRangeFluent<ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<N>>{

        
    public N and();    public N endRange();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1RunAsUserStrategyOptionsFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ExtensionsV1beta1RunAsUserStrategyOptionsFluent<A extends ExtensionsV1beta1RunAsUserStrategyOptionsFluent<A>> extends Fluent<A>{


    public A addToRanges(int index,ExtensionsV1beta1IDRange item);
    public A setToRanges(int index,ExtensionsV1beta1IDRange item);
    public A addToRanges(ExtensionsV1beta1IDRange... items);
    public A addAllToRanges(Collection<ExtensionsV1beta1IDRange> items);
    public A removeFromRanges(ExtensionsV1beta1IDRange... items);
    public A removeAllFromRanges(Collection<ExtensionsV1beta1IDRange> items);
    
/**
 * This method has been deprecated, please use method buildRanges instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1IDRange> getRanges();
    public List<ExtensionsV1beta1IDRange> buildRanges();
    public ExtensionsV1beta1IDRange buildRange(int index);
    public ExtensionsV1beta1IDRange buildFirstRange();
    public ExtensionsV1beta1IDRange buildLastRange();
    public ExtensionsV1beta1IDRange buildMatchingRange(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IDRangeBuilder> predicate);
    public Boolean hasMatchingRange(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IDRangeBuilder> predicate);
    public A withRanges(List<ExtensionsV1beta1IDRange> ranges);
    public A withRanges(ExtensionsV1beta1IDRange... ranges);
    public Boolean hasRanges();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> addNewRange();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> addNewRangeLike(ExtensionsV1beta1IDRange item);
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> setNewRangeLike(int index,ExtensionsV1beta1IDRange item);
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editRange(int index);
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editFirstRange();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editLastRange();
    public ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<A> editMatchingRange(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IDRangeBuilder> predicate);
    public String getRule();
    public A withRule(String rule);
    public Boolean hasRule();
    public A withNewRule(String arg1);
    public A withNewRule(StringBuilder arg1);
    public A withNewRule(StringBuffer arg1);

    public interface RangesNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IDRangeFluent<ExtensionsV1beta1RunAsUserStrategyOptionsFluent.RangesNested<N>>{

        
    public N and();    public N endRange();
}


}
